measuretools.set_always_format_time_signature_of_measures_in_expr
=================================================================

.. autofunction:: abjad.tools.measuretools.set_always_format_time_signature_of_measures_in_expr.set_always_format_time_signature_of_measures_in_expr
   :noindex:
